==> mgpcli-0.1.67.tar.gz: workflow/lib/component/home/application_install.dart <==
import 'dart:convert';
import 'dart:html' as html;

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:qr_flutter/qr_flutter.dart';

import '../../utils/net_util.dart';
import '../widget/hovor_extension.dart';

class ApplicationInstall extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return _State();
  }
}

class _State extends State<ApplicationInstall> {
  String _android_url;
  String _ios_url;
  bool loadFailed = false;

  @override
  void initState() {
    super.initState();
    NetUtils.get('/api/app').then((data) {
      if (mounted) {
        Map map = json.decode(data);
        if (map['code'] == 1) {
          setState(() {
            _android_url = map['data']['android'] as String;
            _ios_url = map['data']['ios'] as String;
            loadFailed = false;
          });
        } else {
          setState(() {
            loadFailed = true;
          });
          Scaffold.of(context).showSnackBar(SnackBar(
            content: Text(map['msg']),
          ));
        }
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: <Widget>[
        Divider(height: 1),
        ListTile(title: Text('安装Sample')),
        Row(
          children: <Widget>[
            DownloadWidget(
              url: _android_url,
              error: loadFailed,
              text: 'Android下载',
              errorString: 'Android地址加载失败',
            ),
            DownloadWidget(
              url: _ios_url,
              error: loadFailed,
              text: 'iOS下载',
              errorString: 'iOS地址加载失败',
            )
          ],
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
        ),
      ],
    );
  }
}

class DownloadWidget extends StatelessWidget {
  const DownloadWidget({
    Key key,
    this.url,
    this.error,
    this.errorString,
    this.text,
  });

  final String url;
  final bool error;
  final String errorString;
  final text;

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        if (url != null && url.startsWith("http")) {
          html.window.open(url, text);
        }
      },
      child: Card(
        margin: EdgeInsets.only(left: 10, right: 10),
        child: Column(children: <Widget>[
          Container(
            height: 130,
            width: 130,
            child: url != null
                ? QrImage(data: url, version: QrVersions.auto, size: 130.0)
                : Center(
                    child:
                        error ? Text(errorString) : CircularProgressIndicator(),
                  ),
          ),
          Center(child: Text(text, style: TextStyle(color: Colors.blue))),
        ]),
      ).pointer,
    );
  }
}

==> mgpcli-0.1.74.tar.gz: workflow/lib/component/home/application_install.dart <==
import 'dart:convert';
import 'dart:html' as html;

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:qr_flutter/qr_flutter.dart';
import 'package:workflow/utils/net_util.dart';

import '../widget/hovor_extension.dart';

class ApplicationInstall extends StatefulWidget {
  @override
  State<StatefulWidget> createState() {
    return _State();
  }
}

class _State extends State<ApplicationInstall> {
  String _androidUrl;
  String _iosUrl;
  bool _loadFailed = false;

  @override
  void initState() {
    super.initState();
    NetUtils.get('/api/app').then((data) {
      if (mounted) {
        Map map = json.decode(data);
        if (map['code'] == 1) {
          setState(() {
            _androidUrl = map['data']['android'] as String;
            _iosUrl = map['data']['ios'] as String;
            _loadFailed = false;
          });
        } else {
          setState(() {
            _loadFailed = true;
          });
          Scaffold.of(context).showSnackBar(SnackBar(
            content: Text(map['msg']),
          ));
        }
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      children: <Widget>[
        DownloadWidget(
          url: _androidUrl,
          error: _loadFailed,
          text: 'Android下载包',
          errorString: 'Android地址加载失败',
          size: 200,
        ),
        Padding(padding: EdgeInsets.only(left: 80)),
        DownloadWidget(
          url: _iosUrl,
          error: _loadFailed,
          text: 'iOS下载包',
          errorString: 'iOS地址加载失败',
          size: 200,
        )
      ],
      mainAxisAlignment: MainAxisAlignment.center,
    );
  }
}

class DownloadWidget extends StatelessWidget {
  const DownloadWidget({
    Key key,
    this.url,
    this.error,
    this.errorString,
    this.text,
    this.size,
  });

  final String url;
  final bool error;
  final String errorString;
  final text;
  final double size;

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        if (url != null && url.startsWith("http")) {
          html.window.open(url, text);
        }
      },
      child: Card(
        child: Column(children: <Widget>[
          Container(
            height: size ?? 122,
            width: size ?? 122,
            child: url != null
                ? QrImage(
                    data: url, version: QrVersions.auto, size: size ?? 122.0)
                : Center(
                    child:
                        error ? Text(errorString) : CircularProgressIndicator(),
                  ),
          ),
          Center(child: Text(text, style: TextStyle(color: Colors.blue))),
        ]),
      ).pointer,
    );
  }
}
